@@ -1,7 +1,11 @@
 #define STRingize(x) #x
 #define STR(x) STRingize(x)
 
+#define MM_MAJOR 0
+#define MM_MINOR 52
+
 #define MM_NAME "MultiMail"
+#define MM_SNAME "MMail"
 #define MM_VERNUM STR(MM_MAJOR) "." STR(MM_MINOR)
 #define MM_TOPHEADER MM_NAME "/%.16s v" MM_VERNUM
 
@@ -10,7 +14,7 @@
 
 /* With the default tar/gz compress command, leave this on. It causes the
    entire file to be rearchived when using that format, instead of just
-   the .red file. If you replace the tar/gz command with something 
+   the .red file. If you replace the tar/gz command with something
    smarter (e.g., via a script), you can disable the kludge.
 */
 #define TAR_KLUDGE
@@ -35,15 +39,11 @@
 
 /* ----- Platform-specific defines ----- */
 
-/* This could be improved on. Currently, it's only written to deal with
-   GCC, DJGPP, EMX, RSX/NT, BCC 5.5, Turbo C++ 3.0, MinGW and Watcom.
-*/
-
 /* HAS_UNAME determines whether the "System" part of the tearline is taken
    from the uname() function, or is hardwired. Turbo/Borland C++ and
-   Watcom don't have it, and it's broken in RSX/NT.
+   Watcom don't have it.
 */
-#if !defined(__RSXNT__) && !defined(__TURBOC__) && !defined(__MINGW32__) && !defined(__WATCOMC__) && !defined(_MSC_VER)
+#if !defined(__TURBOC__) && !defined(__MINGW32__) && !defined(__WATCOMC__) && !defined(_MSC_VER)
 # define HAS_UNAME
 #endif
 
@@ -80,7 +80,7 @@
 /* I use strcasecmp() and strncasecmp() throughout, but some systems call
    these functions stricmp() and strincmp().
 */
-#if defined(__EMX__) || defined(__TURBOC__) || defined(__WATCOMC__) || defined(_MSC_VER)
+#if defined(__TURBOC__) || defined(__WATCOMC__) || defined(_MSC_VER)
 # define USE_STRICMP
 #endif
 
@@ -113,10 +113,10 @@
 # define USE_SETDISK
 #endif
 
-/* In Borland/Turbo C++ and in DJGPP, using findfirst()/findnext() is
-   faster than using readdir()/stat().
+/* In Borland/Turbo C++, using findfirst()/findnext() is faster than
+   using readdir()/stat().
 */
-#if defined(__DJGPP__) || defined(__TURBOC__)
+#ifdef __TURBOC__
 # define USE_DIRH
 # define USE_FINDFIRST
 #endif
@@ -139,13 +139,6 @@
 # define USE_SETFTIME
 #endif
 
-/* MSVC seems to have a nonstandard version of set_new_handler(). It's 
-   not that useful anyway.
-*/
-#ifndef _MSC_VER
-# define USE_NEWHANDLER
-#endif
-
 /* Turbo C++ 3.0 lacks the "bool" and "off_t" types.*/
 
 #ifndef TURBO16
@@ -153,7 +146,7 @@
 # define HAS_OFFT
 #endif
 
-/* Some lines in the code serve no purpose but to supress the GCC warning
+/* Some lines in the code serve no purpose but to suppress the GCC warning
    "might be used uninitialized in this function". Borland C++ 5.5, on the
    other hand, complains "is assigned a value that is never used" if I
    leave these lines _in_.
